@@ -137,7 +137,11 @@ struct passwd *pwp;
 #ifdef BULLDB
    name.dptr = p->user;
    name.dsize = strlen(p->user) + 1;
+#ifdef GDBM
+   bull_count = gdbm_fetch(p->bull_db, name);
+#else
    bull_count = dbm_fetch(p->bull_db, name);
+#endif
    if (bull_count.dptr == NULL) {
       /* If the database does not have a value, check the users .popbull
        * file.  If it's not empty, then use the value there, otherwise,
@@ -161,11 +165,22 @@ struct passwd *pwp;
        /* Block while waiting for a lock to update the entry */
        if (flock(dbm_dirfno(p->bull_db), LOCK_EX) == -1)
 	  return(pop_msg(p, POP_FAILURE, "Bulletin database lock failed"));
+#ifdef GDBM
+	   gdbm_store(p->bull_db, name, bull_count, GDBM_REPLACE);
+#else
        dbm_store(p->bull_db, name, bull_count, DBM_REPLACE);
+#endif
        flock(dbm_dirfno(p->bull_db), LOCK_UN);
 
        if (NEWBULLCNT <= 0)
+	 {
+#ifdef GDBM
+	   gdbm_close(p->bull_db);
+#else
+	   dbm_close(p->bull_db);
+#endif
 	  return POP_SUCCESS;
+	 }
    } else {
 	bcopy(bull_count.dptr, &lastBullSent, bull_count.dsize);
 #else
@@ -197,7 +212,16 @@ struct passwd *pwp;
 
    /* If there aren't any new bulletins for this user, return. */
    if (lastBullSent >= maxBullNumber)
+     {
+#ifdef BULLDB
+#ifdef GDBM
+       gdbm_close(p->bull_db);
+#else
+       dbm_close(p->bull_db);
+#endif
+#endif
        return POP_SUCCESS;
+     }
 
    (void) chmod(popBullName, 0600);   /* Only needs to be read by me */
 
@@ -243,7 +267,13 @@ struct passwd *pwp;
        bull_count.dsize = sizeof(maxBullNumber);
        if (flock(dbm_dirfno(p->bull_db), LOCK_EX) == -1)
 	  return(pop_msg(p, POP_FAILURE, "Bulletin database lock failed"));
+#ifdef GDBM
+       gdbm_store(p->bull_db, name, bull_count, GDBM_REPLACE);
+       gdbm_close(p->bull_db);
+#else
        dbm_store(p->bull_db, name, bull_count, DBM_REPLACE);
+       dbm_close(p->bull_db);
+#endif
        flock(dbm_dirfno(p->bull_db), LOCK_UN);
 #else
        /* Update the user's .popbull file. */
@@ -257,6 +287,15 @@ struct passwd *pwp;
 #endif
     }
 
+#ifdef BULLDB
+#ifdef GDBM
+    gdbm_close(p->bull_db);
+#else
+    dbm_close(p->bull_db);
+#endif
+pop_log(p,POP_PRIORITY, "LOGGING THE CLOSE OF BULLDB");
+#endif
+
     return(res);
 }
 
@@ -403,3 +442,20 @@ POP *p;
     return POP_SUCCESS;
 }
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
