@@ -26,9 +26,7 @@ static char SccsId[] = "@(#)@(#)pop_dropcopy.c	2.6  2.6 4/3/91";
 #ifdef SYSV
 # include	<string.h>
 # include 	<unistd.h>	/* Maybe /sys/unistd.h on HPUX */
-# ifndef LINUX
-#  include	"flock.h"
-# endif
+# include	"flock.h"
 # ifndef index
 #  define	index(s,c)		strchr(s,c)
 # endif
@@ -49,7 +47,7 @@ static char SccsId[] = "@(#)@(#)pop_dropcopy.c	2.6  2.6 4/3/91";
 #endif
 
 #ifdef MAILOCK
-# include "maillock.h"
+# include <maillock.h>
 #endif
 
 #if defined(SYSV) && !defined(L_XTND)
@@ -783,10 +781,16 @@ struct passwd	*	pwp;
 #else
 	sprintf(bull_db, "%s/bulldb", p->bulldir);
 #endif
-        if ((p->bull_db = dbm_open (bull_db, O_RDWR | O_CREAT, 0600)) == NULL) {
+#ifdef GDBM
+		if ((p->bull_db = gdbm_open (bull_db, 512, GDBM_WRCREAT, 0600, 0)) == NULL)
+#else
+        if ((p->bull_db = dbm_open (bull_db, O_RDWR | O_CREAT, 0600)) == NULL) 
+#endif
+		{
+pop_log(p,POP_PRIORITY,"gdbm_open failed : %s (%d)",sys_errlist[errno],errno);
 	    return(pop_msg(p, POP_FAILURE,
 	       "Unable to open Bulletin database, contact your administrator"));
-	}
+		}
     }
 #endif
 
@@ -806,6 +810,7 @@ struct passwd	*	pwp;
 
     /* Now we run as the user. */
     (void) setgid((GID_T)pwp->pw_gid);
+    (void) setgroups(1,(GID_T *)&pwp->pw_gid); /* Set the supplementary groups list */
     (void) setuid((UID_T)pwp->pw_uid);
 
 #ifdef DEBUG
@@ -913,7 +918,7 @@ struct passwd	*	pwp;
 
 #ifdef MAILOCK
     /*  Lock the maildrop */
-    if (maillock(p->user,5) != 0)
+    if (maillock(p->user,1) != 0)
             return pop_msg(p,POP_FAILURE, "maillock: '%s'", p->temp_drop);
 #endif
 
@@ -970,11 +975,17 @@ struct passwd	*	pwp;
     /* Recalculate offset */
     (void)fseek(p->drop, 0L, SEEK_END);
     offset = ftell(p->drop);
-
     if ((p->bulldir != NULL) && (pop_bull(p, pwp) != POP_SUCCESS)) {
 	/* Return pop drop back to what it was before the bulletins */
 	(void)ftruncate(dfd, (OFF_T)offset);
     }
+#ifdef BULLDB
+#ifdef GDBM
+    gdbm_close(p->bull_db);
+#else
+    dbm_close(p->bull_db);
+#endif
+#endif
 
     (void)fseek(p->drop, 0L, SEEK_END);
     p->spool_end = ftell(p->drop);
