@@ -25,6 +25,7 @@ static char SccsId[] = "@(#)@(#)pop_get_command.c	2.1  2.1 3/18/91";
 static state_table states[] = {
         auth1,  "user", 1,  1,  pop_user,   {auth1, auth2},
         auth2,  "pass", 1,  1,  pop_pass,   {halt,  trans},
+        auth1,  "auth", 1,  2,  pop_auth,   {auth1, auth1},
 #ifdef RPOP
         auth2,  "rpop", 1,  1,  pop_rpop,   {halt,  trans},
 #endif
@@ -85,14 +86,20 @@ register char   *   mp;         /*  Pointer to unparsed line
              && s->ValidCurrentState == p->CurrentState) {
 
             /*  Were too few parameters passed to the command? */
-            if (p->parm_count < s->min_parms)
-                return((state_table *)pop_msg(p,POP_FAILURE,
-                    "Too few arguments for the %s command.",p->pop_command));
+            if (p->parm_count < s->min_parms) {
+                pop_msg(p,POP_FAILURE,
+                    "Too few arguments for the %s command.",p->pop_command);
+                return((state_table *)0);
+            }
+            
 
             /*  Were too many parameters passed to the command? */
-            if (p->parm_count > s->max_parms)
-                return((state_table *)pop_msg(p,POP_FAILURE,
-                    "Too many arguments for the %s command.",p->pop_command));
+            if (p->parm_count > s->max_parms) {
+                pop_msg(p,POP_FAILURE,
+                    "Too many arguments for the %s command.",p->pop_command);
+                return((state_table *)0);
+            }
+            
 
             /*  Return a pointer to the entry for this command in 
                 the command/state table */
@@ -100,6 +107,6 @@ register char   *   mp;         /*  Pointer to unparsed line
         }
     }
     /*  The client command was not located in the command/state table */
-    return((state_table *)pop_msg(p,POP_FAILURE,
-        "Unknown command: \"%s\".",p->pop_command));
+    pop_msg(p,POP_FAILURE,"Unknown command: \"%s\".",p->pop_command);
+    return((state_table *)0);
 }
