@@ -43,7 +43,11 @@
 
 #ifdef BULLDB
 # undef	DBM		/* used by mts.c and ndbm.h */
-# include <ndbm.h>
+# ifdef GDBM
+#  include <gdbm.h>
+# else
+#  include <ndbm.h>
+# endif
 #endif
 
 #define NULLCP          ((char *) 0)
@@ -106,15 +110,6 @@
 # define OSDONE
 #endif
 
-#if defined(LINUX)
-# define POP_MAILDIR	"/var/spool/mail"
-# define POP_DROP	"/var/spool/pop/%s.pop"
-# define POP_TMPDROP	"/var/spool/pop/tmpXXXXXX"
-# define POP_TMPXMIT	"/var/spool/pop/xmitXXXXXX"
-# define MAIL_COMMAND	"/usr/sbin/sendmail"
-# define OSDONE
-#endif
-
 #if !defined(OSDONE) && (defined(BSD) && ((BSD) >= 199103))
 # define POP_MAILDIR     "/var/mail"
 # define POP_DROP        "/var/mail/.%s.pop"
@@ -124,7 +119,7 @@
 # define OSDONE
 #endif
 
-#ifndef OSDONE
+#if !defined(OSDONE) && !defined(LINUX)
 # define POP_MAILDIR     "/usr/spool/mail"
 # define POP_DROP        "/usr/spool/mail/.%s.pop"
 # define POP_TMPDROP     "/usr/spool/mail/tmpXXXXXX"
@@ -132,6 +127,14 @@
 # define MAIL_COMMAND	 "/usr/lib/sendmail"
 #endif
 
+#ifdef LINUX
+# define POP_MAILDIR "/var/spool/mail"
+# define POP_DROP    "/var/spool/mail/.%s.pop"
+# define POP_TMPDROP "/var/spool/mail/tmpXXXXXX"
+# define POP_TMPXMIT "/var/spool/mail/xmitXXXXXX"
+# define MAIL_COMMAND "/usr/sbin/sendmail"
+#endif
+
 /*
  * The default string for HOMEDIRMAIL is "%s/.mail".  You need to change
  * the value in pop_dropcopy.h in routine genpath() if you wish to modify
@@ -319,7 +322,11 @@ typedef struct  {                               /*  POP parameter block */
                                                     parsed list */
     char            *   bulldir;                /*  Bulletin directory */
 #ifdef BULLDB
+#ifdef GDBM
+	GDBM_FILE 		bull_db;
+#else
     DBM		    *	bull_db;		/*  Central Bulletin Database */
+#endif
 #endif
     char	    *	mmdf_separator;		/*  string between messages */
     char		md5str[BUFSIZ];		/*  String used with the shared
@@ -359,6 +366,7 @@ extern int  pop_list();
 extern int  pop_pass();
 extern int  pop_rpop();
 extern int  pop_apop();
+extern int  pop_auth();
 extern int  pop_quit();
 extern int  pop_rset();
 extern int  pop_send();
